Mostrando entradas con la etiqueta Excel Services. Mostrar todas las entradas
Mostrando entradas con la etiqueta Excel Services. Mostrar todas las entradas

jueves, 7 de agosto de 2014

Excel Services - "The workbook cannot be opened" Sharepoint 2013

Cuando abro un Excel en Excel Services me lanza el error: "The workbook cannot be opened"

image

Revisando los logs, veo los siguientes errores:

Error 1:

ServerSession.ProcessServerSessionException: An exception during ExecuteWebMethod has occurred for server: http://urlwebapplication:32843/021d25c448d8404da46c5b6ef1609db8/ExcelService*.asmx, method: OpenWorkbook, ex: Microsoft.Office.Excel.Server.CalculationServer.Proxy.ServerSessionException: The workbook cannot be opened..

Error 2:

Result=Microsoft.Office.Excel.Server.CalculationServer.Proxy.ServerSessionException: The workbook cannot be opened.   
at Microsoft.Office.Excel.Server.CalculationServer.Proxy.ServerSession.ExecuteWebMethodCore(WebMethodType webMethodType, WebMethodBehaviorAttribute webMethodBehavior, CommandParameter parameter, CoreWebMethod coreWebMethod)   
at Microsoft.Office.Excel.Server.CalculationServer.Proxy.ServerSession.ExecuteWebMethod(WebMethodType webMethodType, WebMethodBehaviorAttribute webMethodBehavior, CommandParameter parameter, CoreWebMethod coreWebMethod)

EwaState.OpenWorkbookAndUpdateState: errors occurred while trying to open the workbook, [MessageId: GenericFileOpenError, MessageIdHash: -2005647745]

Solución

Ejecuto el siguiente script de powershell

$w = Get-SPWebApplication –Identity <URL of the Web application>
$w.GrantAccessToProcessIdentity("<insert service account>")

La cuenta que debo otorgarle permisos, es la de Excel Services. Para ello realizo los siguientes pasos:

Entro al Central Administration a la sección se Security. “Configure Service Accounts”

image

Elijo la cuenta que se usa para el pool del Service Application de Excel Services. En mi caso era Service Application Pool – Sharepoint Web Services Default, pero puedo variar la cuenta dependiendo como lo tengas configurado.

image

Ej: si la cuenta era DOMINIO\AppPoolDefaultAccount

$w = Get-SPWebApplication –Identity http://url_webApplication

$w.GrantAccessToProcessIdentity("DOMINIO\AppPoolDefaultAccount")

Este comando lo que hace es:

  • Agregar la cuenta que ejecuta Excel Services como usuario en las bases de contenido del web application
  • Otorga a la cuenta que ejecuta Excel Services el rol de SPDataAccess
  • Otorga a la cuenta que ejecuta Excel Services permisos de full control sobre el Web Application vía una policy.

viernes, 13 de junio de 2014

Error con Excel Services al abrir un Excel

Al tratar de abrir un excel de forma online en Sharepoint 2013, me lanzaba el siguiente error.
image
We´re sorry. We ran into a problem completing tour request. Please try that again in few minutes.
Revisando los logs de Sharepoint, aparecería el siguiente error:
Unexpected error when trying to access service settings in the configuration database. Make sure the proxy for this service application is a member of the default proxy group for the active web application. Error = ExcelServerWebServiceApplication.Local: Could not get the web application associated with this context. This indicates that the Excel Server service is not properly registered or provisioned..
Lo que hice fue asociar el service application al web application.
image
Selecciono default
image
marco la opción de Excel Services.
image

domingo, 21 de julio de 2013

Links útiles #43 - Sharepoint 2013

1-Fill Factor para Sharepoint 2013

En la versión de Sharepoint 2010 el fill factor recomendado para los indices era de 80%, en cambio en 2013 ese valor cambio. Este valor indica cuanto puede llenar SQL Server las páginas cuando crea un nuevo índice.

image

http://sharepoint.nauplius.net/2013/04/the-fill-factor-mystery/

2-Social tags en Sharepoint 2013

El artículo nos explica el uso de tags en sharepoint 2013

http://www.chrisweldon.net/blog/2012/12/18/sharepoint-2013-tagging-social-tags/

3-Agregar un proveedor de búsqueda en Internet explorer para que apunte a un Sharepoint Center

image

http://www.ntsystems.it/post/SharePoint-2013-Search-Center-Windows-8.aspx

http://msdn.microsoft.com/en-us/library/dd742958(v=VS.85).aspx

http://sprider.org/2013/04/10/advertise-sharepoint-search-provider-in-internet-explorer/

http://consultingblogs.emc.com/pawangulati/archive/2011/01/10/adding-sharepoint-as-ie-search-provider.aspx

http://lassewikmark.wordpress.com/2010/10/13/integrating-sharepoint-search-with-the-desktop/

4-Shared Workbooks usando Excel Services en Sharepoint 2013

image

image

Excel Services permite compartir contenido de Excel  compartiendo un excel completo o secciones del mismo.

http://technet.microsoft.com/en-us/library/dn198294.aspx

http://www.youtube.com/watch?v=3cwRLDJuM5U

5-Excluir contenido del Spell Check de Sharepoint

image

http://blog.cube4.com.au/?p=1016

miércoles, 6 de febrero de 2013

Links útiles #58–Sharepoint 2010

1-Mantenimiento del User Profile Services en Sharepoint 2010

http://technet.microsoft.com/en-us/library/ff681014(v=office.14).aspx

2-Excel Services vs Reporting Services

http://epmxperts.wordpress.com/2013/01/25/excel-services-vs-ssrs-considerations/

3-Cambiar la url de MySite

http://fangdahai.blogspot.com.ar/2013/01/how-to-change-my-site-host-url.html

4-Jquery y web services Sharepoint 2010

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/retrieving-data-from-sharepoint-list.html

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/bind-html-dropdown-list-using-jquery.html

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/insertion-into-sharepoint-list-using.html

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/updating-single-record-using-jquery-and.html

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/deleting-more-than-one-record-using.html

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/updating-more-than-one-record-using.html

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/inserting-more-than-one-record-using.html

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/delete-single-record-using-jquery-and.html

5-AD RMS Sharepoint 2010

http://tristanwatkins.com/inspecting-ad-rms-request-sharepoint-2010/

viernes, 18 de enero de 2013

Links útiles #16 Sharepoint 2013

1-Autohosted Sharepoint 2013 Apps

http://chakkaradeep.com/index.php/autohosted-sharepoint-apps-deep-dive-part-1

2-Access request and Invitations en Sharepoint 2013

http://www.learningsharepoint.com/2013/01/07/sharepoint-2013-the-new-access-requests-and-invitations-feature-2/

3-BCS con SQL Azure en Sharepoint 2013

http://blog.pointbeyond.com/2012/12/31/surfacing-data-from-sql-azure-in-sharepoint-2013-online-office-365/

4-Excel Services Sharepoint 2013

http://www.techbubbles.com/sharepoint/configuring-excel-services-in-sharepoint-2013/

5-Distributed Cache Services

http://salvatoredifaziosharepoint.blogspot.com.ar/2013/01/some-improvements-from-sp2013.html

6-Ordenar resultados vía query string con ResultScriptWebPart en Sharepoint 2013

http://www.dotnetmafia.com/blogs/dotnettipoftheday/archive/2013/01/09/how-to-sort-search-results-by-query-string-with-the-resultscriptwebpart-in-sharepoint-2013.aspx

7-Lo nuevo en mobile para Sharepoint 2013

http://darrinbishop.com/blog/2013/01/whats-new-in-mobile-for-sharepoint-2013-part-1

8- SSL y certificados en Sharepoint 2013

http://blog.karstein-consulting.com/2013/01/08/create-provider-hosted-high-trust-app-for-sharepoint-2013-short-guide/

9-Language Packs para Sharepoint 2013

http://weblogs.asp.net/sreejukg/archive/2013/01/08/apply-language-packs-to-sharepoint-2013.aspx

10-Pasar parámetros a un client web part en Sharepoint 2013

http://www.dotnetmafia.com/blogs/dotnettipoftheday/archive/2013/01/04/how-to-pass-parameters-to-a-client-web-part.aspx

sábado, 4 de agosto de 2012

Tips / Info #55 Sharepoint 2010

1-Autenticación via forms en Client Object Sharepoint 2010

ClientContext ctx = new ClientContext(url_Site);
ctx.AuthenticationMode = ClientAuthenticationMode.FormsAuthentication;
ctx.FormsAuthenticationLoginInfo = new
                    FormsAuthenticationLoginInfo(myUserName, myUserPwd);

Web w = ctx.Web;

var lists = ctx.LoadQuery(w.Lists);

ctx.ExecuteQuery();

foreach (List theList in lists)
{//hago algo con las listas   

}

2-Application Pages en Sharepoint 2010, acceso anónimo

Si deseas un application page en Sharepoint 2010 que sea accesible por usuarios anónimos, deberás cambiar la herencia en tu página, de LayoutsPageBase a UnsecuredLayoutsPageBase.

LayoutsPageBase_01

Y agrega el siguiente método:

protected override bool AllowAnonymousAccess { get { return true; } }

Páginas derivadas de esta clase siempre residen en el folder _layouts, pueden contener código pero no pueden contener WebParts personalizadas o Zonas de WebParts. La ventaja primordial de esta herencia es que se puede acceder fácilmente todos los objetos de SharePoint por medio de las propiedades y el control de seguridad de la página (SPContext).

3-Errores del query component

Si en el event viewer aparece :

    1. Query 0, catalog Main: failing to copy index files from crawl component

   2. Query 0 is not being automatically disabled because the minimum number of ready query components per partition is 2.

Esto se debe a que el query componente no está respondiendo. Cuando que query componente no responde la búsqueda no indexa el nuevo contenido de los sites, ya que el crawling status no cambiará.

La resolución es crear un nuevo query componente y cambiar la ubicación de la propagación del search service.

stsadm -o osearch -propagatelocation “C:\Search\ApplicationCrawl″

A continuación ejecuta lo siguiente en una línea de comando:

stsadm -o osearch stop

stsadm -o osearch start -role query

4-No es posible crear un DataSource en Dashboard Designer con Excel Services

dashboard-designer-error

La causa es que se tiene habilitado Acceso anónimo en el IIS para el web application al cual quiere conectarse.

disableanonymousauthentication

5-Sharepoint 2010 me lanza el error “An unexpected error has occurred.” al subir un archivo con una longitud de nombre mayor que 125 caracteres.

La única manera de solucionarlo, es achicar el nombre del archivo.

sábado, 7 de julio de 2012

Links útiles #42 Sharepoint

1-Mostrar web parts de charts con fuentes de datos de excel services

http://www.dotnetcurry.com/ShowArticle.aspx?ID=816

2-AppFabric y Sharepoint 2010

http://www.wictorwilen.se/Post/Improve-performance-of-your-SharePoint-2010-applications-using-Windows-Server-AppFabric-caching.aspx

3-Porqué LINQ to Sharepoint es malo para el desarrollo ?

http://blog.furuknap.net/why-linq-to-sharepoint-is-a-bad-idea

4-Recover data from an unattached content database

http://jmhogua.blogspot.com.ar/2012/07/recuperando-un-documento-de-una-base-de.html

5-Crear una feature en Visual Studio 2010

http://salaudeen.blogspot.com.ar/2012/05/how-to-create-feature-in-sharepoint.html

6-Crear una application page en Sharepoint 2010

http://salaudeen.blogspot.com.ar/2012/07/how-to-create-custom-application-page.html

7-Windows AZURE / Sharepoint 2010 / REST / JSONP

http://blogs.msdn.com/b/steve_fox/archive/2012/07/01/jsonp-sharepoint-online-amp-windows-azure.aspx

8-Sección del web.config relacionada a Sharepoint 2010

http://www.gavd.net/servers/sharepoint/sps_item.aspx?top=wps&itm=119

9-Crear un external content type mediante Visual Studio 2010

http://sharepointjourney.wordpress.com/2012/07/05/creating-an-external-content-type-using-the-visual-studio-2010-bdc-model-project-template-and-extend-the-external-content-type/

10-Rebuild de un web application (Nuevo web application misma base de contenido)

http://mmman.itgroove.net/2011/12/rebuilding-a-web-application-in-sharepoint-central-admin-data-non-destructive/

Tips/Info #45 Sharepoint

1-Permisos necesarios para la cuenta que corre el servicio SPTimerV4 (Sharepoint Service Timer)

  • Verificar que la cuenta de usuario es miembro del grupo Administrator de todos los servers de la granja.
  • Confirmar que la cuenta de usuario tiene los siguientes roles sobre el sql server
    • dbcreator
    • securityadmin
    • db_owner para todas las bases de datos de la granja

2-Excel REST Services

Si tienes un excel en la libreria Shared Documents,
http://Foo/Site/Shared Documents/ejemplo.xlsx
entonces la URL del servicio REST será la siguiente
http://Foo/Site/_vti_bin/ExcelRest.aspx/Shared Documents/ejemplo.xlsx
Los formatos disponibles para renderizar contenido son los siguientes:

?$format=html  - renderiza como html, para tablas y pivot tables
?$format=atom  - provee un ATOM feed
?$format=image - Renderiza una imagen PNG, sólo soportado para Charts
?$format=workbook - Se descarga el workbook

/_vti_bin/ExcelRest.aspx/Shared Documents/ejemplo.xlsx/Model/Ranges('Sheet1!A2|H8')?$format=html - De la hoja 1,obtiene los datos del rango específico y renderiza HTML.
/_vti_bin/ExcelRest.aspx/Shared Documents/ejemplo.xlsx/Model/Charts(‘ValoresChart’)?$format=image - Obtiene el chart y lo renderiza como una imagen PNG

El siguiente link informa sobre las funcionalidades no admitidas de EXCEL REST SERVICES:http://msdn.microsoft.com/es-ar/library/ff394477

3-Services Applications disponibles por versión

Service Application

Edition

Business Connectivity Service SharePoint Foundation 2010
Usage and Health Data collection SharePoint Foundation 2010
Subscription Setting Service SharePoint Foundation 2010
User Profile SharePoint Server 2010 Standard Edition
Managed Metadata Service SharePoint Server 2010 Standard Edition
Search SharePoint Server 2010 Standard Edition
Secure Store Service SharePoint Server 2010 Standard Edition
State SharePoint Server 2010 Standard Edition
Web Analytics SharePoint Server 2010 Standard Edition
Word Automation Services SharePoint Server 2010 Standard Edition
Access Services SharePoint Server 2010 Standard Edition
Excel Services Application SharePoint Server 2010 Enterprise Edition
PerformancePoint Service Application SharePoint Server 2010 Enterprise Edition
Visio Graphics Service SharePoint Server 2010 Enterprise Edition

4-Error: Bad Request (Request Header too long)

Si estás guardando un form de infopath y te lanza este error, deberás hacer lo siguiente:

Abre el notepad y escribe lo siguiente, y guardalo con extensión .reg :

Windows Registry Editor Version 5.00
[HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\HTTP\Parameters]
"MaxRequestBytes"=dword:00500000
"MaxFieldLength"=dword:00065534

Ejecuta este archivo, previo backup del registro de windows.

Bad Request (Request Header Too Long) Reg Fix

5-No permitir borrar una lista en sharepoint 2010

PS > $spWeb = Get-SPWeb http://sharepointSite.com
PS > $spList = $spWeb.Lists["Tareas"]
PS > $spList.AllowDeletion = $false
PS > $spList.Update()
PS > $spWeb.Dispose()

miércoles, 27 de junio de 2012

Links útiles #39 Sharepoint 2010

1-Leer datos de un excel mediante Excel Services y C#

http://sharepointontop.blogspot.ca/2012/05/how-to-programmatically-read-data-from.html

2-Iniciar un workflow mediante programación

http://mmasoodblog.wordpress.com/2012/06/18/programatically-start-a-workflow/

3-Obtener información del usuario actual mediante infopath

http://jerryleiarnold.wordpress.com/2012/06/19/infopath-get-current-user-information-2010/

4-Cómo Maneja Microsoft sus Sharepoint (recomendado)

http://channel9.msdn.com/Events/TechEd/NorthAmerica/2012/OSP232

5-Navegación global custom mediante css

http://chrisstahl.wordpress.com/2010/11/04/customizing-sharepoint-2010-global-navigation-with-css-and-jquery-2/

6-Visio Services API: javascript

http://es.scribd.com/doc/56685592/Visio-2010-Mashup-API-Walk-Thru

http://blogs.msdn.com/b/visio/archive/2010/02/21/the-visio-services-javascript-mashup-api.aspx

http://marriedtosharepoint.com/tag/new-window/

http://www.aboutworkflows.com/2012/06/visio-services-2010-how-to-create.html#more

http://msdn.microsoft.com/en-us/library/ff394663

http://msdn.microsoft.com/en-us/library/ff394649.aspx

http://msdn.microsoft.com/en-us/library/ff394484.aspx

7-Conversión de docs a pdf en un event receiver (ItemAdded)

http://suneet-sharma.blogspot.com.ar/2012/06/word-document-to-pdf-conversion-in.html

8-Dar permisos mediante un event receiver (itemadded)

http://extendtheenterprise.com/2012/06/20/item-event-receiver-that-updates-permissions-using-itemadded-override/

9-Un timer job más liviano en Sharepoint

http://www.sharepointboost.com/blog/creating-a-lightweight-timer-job-for-a-site-collection-defining-custom-work-items/

10-Custom Claims Provider Sharepoint 2010

http://visualstudiogallery.msdn.microsoft.com/bba61404-1062-4011-a388-e32605340515

lunes, 18 de junio de 2012

sábado, 16 de junio de 2012

Links útiles #34 Sharepoint 2010

1-Crear un campo custom para Sharepoint con Visual Studio 2010

http://www.c-sharpcorner.com/uploadfile/Roji.Joy/creating-a-custom-field-type-for-sharepoint-2010-email-validation-field/

2-PageQueryString y PageFieldValue en el content query web part

http://sharepointnadeem.blogspot.com.ar/2011/09/cqwp-pagequerystring-and-pagefieldvalue.html

3-Mover el server de search: detener el componente de query

http://www.pbnet.ro/?p=158

4-Reemplazar un web part por otro tipo de web part vía powershell

http://blog.falchionconsulting.com/index.php/2012/06/replace-sharepoint-2010-web-parts-by-type/

5-Footer para Sharepoint 2010

http://erikswenson.blogspot.com.ar/2012/06/fix-long-quick-launch-flowing-over.html

6-Sharepoint 2010 y Reporting Services 2012 Arquitectura de endpoints

http://blogs.msdn.com/b/jtarquino/archive/2012/06/13/sql-server-reporting-services-2012-sharepoint-integrated-mode-endpoints-architecture-or-how-our-services-talk-each-other.aspx

7-Cambiar el resaltado de los resultados de Búsqueda

http://spforsquirrels.blogspot.com.ar/2012/06/sharepoint-2010-search-change-style-of.html

8-Workflows: Columnas asociadas y parámetros

http://blogs.msdn.com/b/sharepointdesigner/archive/2011/07/08/understanding-workflow-starting-parameters-part-1.aspx

http://blogs.msdn.com/b/sharepointdesigner/archive/2011/05/02/association-columns.aspx

9-Sharepoint Server 2010 vs Sharepoint 2010 ONLINE (cloud)

http://www.catapultsystems.com/CatapultEventCalendarInvites/SPUG%20Presentations/SharePoint%20Server%20vs%20SharePoint%20Online%20-%20Final.pdf

10-Mostrar un gráfico (charts web parts) con Excel Services

http://www.dotnetcurry.com/ShowArticle.aspx?ID=816

jueves, 24 de mayo de 2012

Tips /Info # 26 Sharepoint 2010

1-Ocultar la opción “Download a copy” de la ribbon

<style>
A[id$='Ribbon.Documents.Copies.Download-Large'] {
    DISPLAY: none
}</style>

2-Cambiar la URL de un site collection

Sharepoint 2010 no dispone de un mecanismo para cambiar la url de un site collection. Lo que se debe hacer es hace run backup y restore del site collection

Backup-SPSite -Identity http://sharepoint/sitios/originalsite -Path c:/backupsite
Remove-SPSite -Identity http://sharepoint/sitios/originalsite
Restore-SPSite -Identity http://sharepoint/sitios/nuevossite -Path c:/backupsite

3-Query: cantidad de items agrupados por lista

select webs.Title,webs.FullUrl, tp_Title,UserDataCount,DocsCount
from AllLists left outer join
(select tp_ListId, COUNT(*) as UserDataCount from AllUserData
group by tp_ListId ) E On E.tp_ListId = AllLists.tp_ID
left outer join
(select ListId, COUNT(*) as DocsCount from dbo.Docs
group by ListId ) P ON AllLists.tp_ID = P.ListId
left outer join Webs ON AllLists.tp_WebId = Webs.id
order by DocsCount desc



UserDataCount : cantidad de registros almacenadps en la tabla AllUserData para la lista. (item borrados no se incluyen)
DocsCount : cantidad de registros almacenadps en la tabla AllDocs para la lista

(item borrados no se incluyen)

4-Error 404 al atachar (Attach) una base de contenidos


Suele pasar el problema cuando removes la base de contenido desde la UI del Central Administration, desde ese momento no podrás atachar más base de contenidos desde la UI. Se puede realizar mediante powershell:


Detach content database:

Dismount-SPContentDatabase “nombre de la base de contenido”

Attach content database:

Mount-SPContentDatabase “nombre de la base de contenido” -DatabaseServer “nombre o alias del sql server” -WebApplication http://webapplicationURL

5-Setear el outgoing mail para un Web Application mediante powershell

Set-SPWebApplication -Identity http://webapplicationURL -OutgoingEmailAddress mail@email.com –SMTPServer smtp.server.com

6-Columna lookup en CAML Javascript Client Object Model

Prestar atención el atributo LookupId
var list = web.get_lists().getById('<Projects List GUID>');
var query = '<View Scope=\'RecursiveAll\'>'+
'<Query>'+
'<Where>'+
'<Eq>'+
'<FieldRef Name=\'Cliente\' LookupId=\'TRUE\'/>' +
'<Value Type=\'Lookup\'>' + chosenoption.value +'</Value>'+
'</Eq>'+
'</Where>'+
'</Query>'+
'</View>';
7-Error “Unable to process the request” al usar Excel Services
Este error se debe a un error de comunicación con el servicio de excel, haga un iisreset.

8-Verificar si una lista existe o no mediante Server Object


SPList myList = SPContext.Current.Web.Lists.TryGetList(“ListaAVerificar”);
if(myList!=null)
{
    // existe lista
}

9-Error: “The Maximum number of webparts for all zones on this page has been exceeded“

Por default, el límite máximo de web parts por páginas aspx es de 50.


Si desea elmininar un web part podrá hacerlo mediante el querystring contents=1,nos ofrecerá la página de mantenimiento.


10-Error “Cannot find property named PROPERTYNAME on activity type ACTIVITYNAME” al diseñar una actividad de workflow custom


Cierre Sharepoint Designer y borre el contenido de las siguientes carpetas:


C:\Users\<username>\AppData\Local\Microsoft\WebsiteCache


C:\Users\<username>\AppData\Roaming\Microsoft\SharePoint Designer

jueves, 17 de mayo de 2012

Tips/Info #21 Sharepoint 2010

1-Obtener los archivos wsp deployados

$miGranja = Get-SPFarm
$miWSP = $miGranja.Solutions.Item(“SharePointSolution.wsp”).SolutionFile
$miWSP.SaveAs(“C:\Downloads\SharePointSolution.wsp”)



2-Deshabilitar loopback check con powershell

New-ItemProperty HKLM:\System\CurrentControlSet\Control\Lsa -Name “DisableLoopbackCheck” –value “1″ -PropertyType dword

Más info: http://www.gavd.net/servers/sharepointv3/spsv3_item.aspx?top=4&itm=1041


3-Borrar una lista con stsadm


stsadm.exe -o forcedeletelist -url http://myserver:8080/Lists/Team%20Discussion

4-Obtener el path de la carpeta 14 con programación

SPUtility.GetGenericSetupPath(String.Empty)

Ej: si se mantuvo el default de path, se obtendrá: C:\Program Files\Common Files\Microsoft Shared\Web Server Extensions\14

Si deseas una carpeta específica podrás usar el método de la siguiente manera:

SPUtility.GetGenericSetupPath(@"TEMPLATE\FEATURES\")

Obtendrás: C:\Program Files\Common Files\Microsoft Shared\Web Server Extensions\14\TEMPLATE\FEATURES\


5-El comando Export –SPWeb lanza el siguiente error: “There is not enough space on the disk“


El comando exporta todo el contenido a la carpeta TEMP de windows (variable de ambiente %TEMP%), si el disco donde está ubicado este path no tiene espacio, nos lanza este errror. Una solución es cambiar la variable de entorno para que apunte a otra partición o disco.


6-Eligiendo el tipo de definición de job


Los jobs pueden heredar de las siguientes clases del namespaces Microsoft.SharePoint.Administration






























SPAdministrationServiceJobDefinitionInvoca el SharePoint Administration Service
SPAllSitesJobDefinitionItera sobre todos los sitios en una Web Application
SPContentDatabaseJobDefinitionSe ejecuta por Web Application y cada Content Databasees procesada por jobs individuales (es Pausable)
SPFirstAvailableServiceJobDefinitionTimer Job que ejecuta sobre el primer servidor disponible donde el servicio específico existe(es Pausable)
SPJobDefinitionClase base para los Timer Jobs (RECOMENDADO 1)
SPPausableJobDefinitionTimer Job que puede ser pausado
SPServerJobDefinitionEjecutado en un  servidor específico (Pausable)
SPServiceJobDefinitionSe ejecuta en cada servidor de la granja, donde existe el servicio (pausable). RECOMENDADO 2
SPWorkItemJobDefinitionFunciona con el  Timer Job para procesar items de trabajo (Pausable)

7-Manejadores de eventos sobre workflows Sharepoint 2010 (SPWorkflowEventReceiver)


  • Cuando el flujo de trabajo está empezando (WorkflowStarting)
  • Cuando se inicia el flujo de trabajo (WorkflowStarted)
  • Cuando el flujo de trabajo se ha completado (WorkflowCompleted)
  • Cuando el flujo de trabajo se pospone (WorkflowPostponed)

  • Más info: http://www.sharepointkings.com/2012/05/workflow-event-handlers-in-sharepoint.html


    8-Permiso: View Usage Data  -  View reports on Web site usage.


    Permite ver los informes, pero no otorga permisos de administración.


    9-Error "Workbook is larger than the maximum workbook size" Excel Services


  • Ir al Central Administration
  • Click en Application Management
  • Click en Manage Service Applications
  • Click en Excel Service Application
  • Click en Trusted File Locations y después agregar la ubicación del file donde se encuentra y en la propiedad “Maximum Workbook Size” en la sección Workbook Properties editar el campo con el tamaño adecuado.

  • 10-Obtener el tamaño de las content databases con powershell


    Get-SPDatabase | Sort-Object disksizerequired -desc | Format-Table Name, @{Label ="Size(MB)"; Expression = {$_.disksizerequired/1024/1024}}


    11-Recalcular el almancenamiento de los sitios


    $URL = "http://sitio2010”

    $Site = Get-SPSite -identity $URL

    $Site.RecalculateStorageUsed()

    12-Error: An error occurred in the claim provider configured for this Site Collection


    Agregar la url en la sección de  Alternate Access Mapping de la Central Admin

    viernes, 11 de mayo de 2012

    Tips/Info #19 Sharepoint 2010

    1-Comando de powerShell para listar todas las bases de datos de Sharepoint
    Get-SPDatabase | select Name |Format-List > C:\Script\listaDB.txt
    2-Algunos grupos de Sharepoint
    Sobre la key “HKLM\Software\Microsoft\Shared Tools\Web Server Extensions\14.0\Secure” los siguientes grupos deben tener permisos implícitos:
    * WSS_WPG Read permission
    * WSS_Admin_WPG Full Control
    * WSS_RESTRICTED_WPG_V4 Full Control
    image-thumb2
    3- Error 0x800700DF: The file size exceeds the limit allowed and cannot be saved
    Primero verifica que Sharepoint tiene configurado correctamente la quota de upload (Central Administration -> Application Management -> Manage Web Applications->Seleccionar web application y en la ribbon elegir General Settings, verifica la sección de Maximun Upload Size)
    Si tiene configurado correctamente, entonces el problema se debe al servicio WebClient del usuario conectado.
    Vaya a la clave de registro : HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\WebClient\Parameters
    Click derecho sobre FileSizeLimitInBytes y después modificar. Click en decimal y tipear 4294967295 (7fffffff).
    Reiniciar Web Client service (ingresar desde services.msc, y elegir WebClient). A veces es necesario reiniciar la máquina.
    Esto incrementará el tamaño máximo del Web Client a 4Gb, lo cual es lo máximo que puede subir usando WebDAV.
    4- Obtener el ID del site
    Ir a la opción de Manage Content and Structure (http://site/_layouts/sitemanager.aspx)
    Cick derecho sobre el site, y elegir propiedades. Copiar el link:
    image_thumb1
    La opción marcada en negrita es el id del site.
    javascript:__doPostBack('TreeView1','sSPWeb:43ac1eb3-9695-4ca2-aea0-d0b989becd7f:\\SPWeb:21be8303-2880-45d8-848d-330883cd892e:')
    5- Saber el espacio ocupado de un sitio mediante una consulta a base de datos
    SELECT FullUrl AS SiteURL,Id as SiteID,(DiskUsed/1024) AS SiteCollectionStorageUsed from dbo.Sites   WHERE FullUrl like '%urldelsite%' 

    6- BCS y Limitaciones de listas externas


  • Workflows no pueden ser configurados para listas externas
  • No puede crear políticas de administración de información
  • No tiene versionado ni historial
  • No permite editar inline o en datasheet
  • No se permite ratings
  • Si RSS feed
  • No se puede usar REST con listas externas o web services defaults (ListData.svc)
  • No se puede configurar permisos a nivel de item
  • No se puede usar adjuntos
    7-Ocultar la sección “Recently Modified”

    image_thumb

    Abrir el master page V4.master y agregar lo marcado en rojo en el placeholder PlaceHolderLeftActions
    <asp:ContentPlaceHolder id="PlaceHolderLeftActions" runat="server" Visible="false">            
    </asp:ContentPlaceHolder>
    Otra manera es ocultando la sección con css
    <style type="text/css">
        .s4-recentchanges
        {
            display:none;
        }
    </style>

    8-Caracteres extraños en la barra de navegación superior (Ej: FAQ´s aparece como FAQ&#39;s)

  • Busca el menú control de menú con ID TopNavigationMenuV4, y editar la propiedad EncodeTitle="false"

    9- Error en una llamada Excel Services REST (ExcelRest.aspx) This workbook cannot be opened because it is not stored in an Excel Services Application trusted location

    Ir a l Central Administration, después a la sección Manage service applications, y después haga click (marcar y seleccionar manage) en Excel Services Application. Después en Trusted File Locations agregar la locación del archivo que se quiere consumir como Trusted File Location.

    10-Descargar una template de lista en Sharepoint 2010 (List template gallery)

    Entrar a http://spssite/_catalogs/lt/Forms/AllItems.aspx

    sábado, 5 de mayo de 2012

    Links útiles #19–Sharepoint 2010

    1-SSRS 2008 vs SSRS 2012 performance comparación

    http://ghamson.wordpress.com/2012/04/30/ssrs-web-part-performance-2008-r2-vs-2012-initial-results-sharepoint-sp2010-in/

    2-Deployar archivos de recursos sobre App Global resources

    http://blogs.msdn.com/b/yojoshi/archive/2012/04/29/easy-way-to-deploy-resx-resource-files-under-app-globalresources-folder-in-sharepoint-2010.aspx

    3-Lo que tendrá Sharepoint 2013 / Sharepoint 15

    http://www.bibamusmoriendumest.com/?p=33

    4-Customizar los resultados de búsqueda de Sharepoint 2010

    http://www.c-sharpcorner.com/UploadFile/Roji.Joy/how-to-customize-search-results-in-sharepoint-2010/

    5-Desarrollo de un web part desde cero

    http://sharepoint-tutorial.net/post/2012/03/12/web-part-development.aspx

    6-Restear la cache de configuración de Sharepoint mediante powershell

    http://blogs.code-counsel.net/Wouter/Lists/Posts/Post.aspx?List=c04a88a9-d138-4ac3-a2bb-b95c9fdd114e&ID=166

    http://woutersdemos.codeplex.com/releases/view/85474

    7-Migrar MySiste Sharepoint 2007 a Sharepoint 2010

    http://www.mssqltips.com/sqlservertip/2697/how-to-migrate-sharepoint-2007-my-sites-databases-to-sharepoint-2010/

    8-SharePoint Enterprise Search API y Client Object search

    http://www.fewlines4biju.com/2012/05/sharepoint-search-through-server-object.html

    http://www.sharepointblues.com/2010/02/15/content-queries-using-sharepoint-enterprise-search-api/

    http://amykinsgardiner.blogspot.com.ar/2010/12/microsoftofficeserversearchqueryfulltex.html

    http://platinumdogs.me/2012/03/12/sharepoint-using-the-contains-predicate-with-fulltextsqlquery/

    9-Listar todas las features (caracteristicas) de la granja en Powershell

    http://jimehrenberg.wordpress.com/2012/05/02/list-all-installed-features-on-the-farm-via-powershell/

    10-Todo sobre Dependencia de features

    http://sharepoint.microsoft.com/Blogs/GetThePoint/Lists/Posts/Post.aspx?List=8d9e2a99-f288-47c2-916b-2f32864f7b82&ID=607&Web=5e4647a0-e7d0-4626-b71c-b1ff06402465

    11-Configurar Excel Services

    http://algomasdems.blogspot.com.ar/2012/04/problemas-excel-services-sharepoint.html

    12-Sharepoint Designer: hacer un restore de una versión de un workflow

    http://www.sharepoint911.com/blogs/laura/Lists/Posts/Post.aspx?ID=173

    13-Scripts útiles de PowerShell

    Sincronizar imagen de AD con Sharepoint 2010: http://gallery.technet.microsoft.com/scriptcenter/Sync-AD-PictureUrl-with-62901311

    Identificar donde se usa un web part: http://gallery.technet.microsoft.com/scriptcenter/Find-Web-parts-in-20519cf6

    Encontrar los lugares donde está la herencia cortada: http://gallery.technet.microsoft.com/scriptcenter/Find-Broken-Inhertitance-be991a85

    14-RSS de una vista de Sharepoint 2010

    http://www.dummies.com/how-to/content/view-and-read-rss-feeds-in-sharepoint-2010.html

    http://www.sharepointblog.co.uk/2012/05/sorting-a-sharepoint-rss-feed/

    15-Crear un tempate de definición de lista con Visual Studio 2010

    http://parwejpathan.blogspot.com.ar/2012/04/create-of-list-template-list-definition.html

    http://parwejpathan.blogspot.com.ar/2012/04/sharepoint-create-list-template-list.html

    16-Mostrar de forma embebida presentaciones de powerpoint en un frame

    http://ventigrate.codeplex.com/wikipage?title=Permissive%20XFrame%20Header

    http://parwejpathan.blogspot.com.ar/2012/03/embedding-dynamic-powerpoint-decks-into.html

    17-Todo sobre Sharepoint 2010 features

    http://parwejpathan.blogspot.com.ar/2012/03/basics-of-sharepoint-features.html

    18-Extensiones para Visual Studio para desarrollar con Sharepoint 2010

    http://cksdev.codeplex.com/

    http://visualstudiogallery.msdn.microsoft.com/c16038c7-b4f8-41d8-adaa-35beedf6f110 (más info: link)

    viernes, 6 de abril de 2012

    Tips/info #13–Sharepoint 2010

    1-Soporte para mirroring de base de datos en Sharepoint 2010

    hay dos bases de datos que no tienen soporte para mirroring

    • User Profile Service: Synchronization database
    • Web Analytics Service: Staging database

    http://technet.microsoft.com/en-us/library/cc748824.aspx

    2-Características no soportadas para excel services en Sharepoint 2010

    • Comentarios de celdas
    • Referencias de fórmulas a libros externos
    • Query tables (conocidos como external data ranges).
    • Microsoft Visual Basic for Applications (VBA).
    • Cualquier tecnología OfficeArt. Ej, Shapes, WordArt, SmartArt, organization chart, diagrams, signature lines, ink annotations, etc.

    3-Rompiendo la herencia de seguridad de una lista mediante Client Object

       1:  using System;
       2:  using Microsoft.SharePoint.Client;
       3:  using SP = Microsoft.SharePoint.Client;
       4:   
       5:  namespace Microsoft.SDK.SharePointServices.Samples
       6:  {
       7:      class BreakSecurityInheritance
       8:      {
       9:          static void Main()
      10:          {
      11:              string siteUrl = "http://MyServer/sites/MySiteCollection";
      12:              ClientContext oContext = new ClientContext(siteUrl);
      13:              SP.List oList = oContext.Web.Lists.GetByTitle("Announcements");
      14:   
      15:              oList.BreakRoleInheritance(true, false);
      16:   
      17:              oContext.ExecuteQuery();
      18:          }
      19:      }
      20:  }




    Más info: http://msdn.microsoft.com/en-us/library/ee535228.aspx


    4- Opción Accuracy Index en el panel de refinamiento



    Hay algunos conceptos erroneos con respecto al panel de refinamiento y cómo se general los refinamientos. A continuación los conceptos erroneos:




    • Los refinamientos son generados del conjunto completo de resultados de búsqueda


    • Los refinamientos son generados de la primera página de los resultados de búsqueda


    • Los refinamientos son generados de forma random

    Ninguno de estos conceptos son correctos, los refinamientos son generados en base a una propiedad del panel de refinamiento: Accuracy Index.



    image_thumb


    Define cuántos elementos se consideran en la creación de los refinamientos. Por defecto se establece en 50 de modo que sólo los primeros 50 elementos en sus resultados de búsqueda se utiliza para generar los refinamientos.




    • Esto tiene varias consecuencias importantes:
      Si usted tiene más de 50 resultados (por ejemplo 20000) podría haber algunas categorías de refinamiento que no aparecen porque no están en los primeros 50 resultados


    • Si usted tiene contadores para los refinamientos, verá que el número total contadores podría no sumar el número total de resultados.

    Sin embargo, usted puede aumentar este valor hasta un máximo de 500. Si usted quiere ser capaz de generar refinamientos para todos los resultados de búsqueda, llamados deep refiners, entonces usted tendrá que usar FAST Search.


    Entre más refinamientos tengas, menor performance tendrá en la consulta.


    5-Mostrar contadores en el panel de refinamiento



    Hacer click en “Filter Category Definition” en el web part de panel de refinamiento.



    image_thumb1


    En la categoría deseada, ej: Title, agregar ShowCounts=”Count”


    image_thumb2


    La inclusión del contador es determinado por xlst en el web part de refinamiento.


    image_thumb3


    6-Evitar dos llamadas a ItemUpdating después de subir un documento a una document library



       1:  public override void ItemUpdating(SPItemEventProperties properties)
       2:    {  
       3:      base.ItemUpdating(properties);
       4:      if (properties.AfterProperties["vti_sourcecontrolcheckedoutby"] == null && properties.BeforeProperties["vti_sourcecontrolcheckedoutby"] != null)
       5:       {
       6:         //do stuff
       7:       }
       8:    }




    Más info: http://www.simple-talk.com/content/print.aspx?article=1424


    7-Habilitar HTML 5 en Sharepoint 2010



    En tu master page default, buscar la siguiente línea:


    <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"> 

    Modificarla por:

    <!DOCTYPE html>

    Después modifica la siguiente línea:

    <meta http-equiv="X-UA-Compatible" content="IE=8"/>

    Por la siguiente:

    <meta http-equiv="X-UA-Compatible" content="IE=9"/>









    8-Error: al abrir un archivo word desde Sharepoint 2010



    Word experienced an error trying to open the file.

    Try these suggestions.

    * Check the file permissions for the document or drive.

    * Make sure there is sufficient free memory and disk space.

    * Open the file with the Text Recovery converter.

    word_error



    Para solucionarlo, ir a File/Options/Trust Center/Trusted Center Settings.


    Después seleccionar la sección Protected View, y desmarcar todas las opciones.


    protected_view-300x172



    9-Donde crear un servicio de WCF en Sharepoint 2010



    Si está creando un servicio WCF básicamente tienes dos opciones:
    -Crear un servicio WCF en un contexto de SharePoint.
    -Crear un servicio WCF independiente.



    Si está creando un servicio WCF en un contexto de SharePoint, básicamente hará lo siguiente: crear un proyecto de SharePoint, agregue el servicio WCF y desplegar a la carpeta ISAPI. Véase: http://msdn.microsoft.com/en-us/library/ff521581.aspx  para obtener más información. Además, puede utilizar http://cksdev.codeplex.com/  , que contiene una plantilla WCF útil.



    Si está creando un servicio WCF independiente, básicamente creará un proyecto WCF y publicar el servicio. Ver
    http://sharepointdragons.com/2011/10/07/parallel-programming-in-sharepoint-2010-the-back-to-the-future-pattern/



    ¿Por lo tanto, a la hora de elegir uno de los dos escenarios, cuál es la mejor práctica, y por qué?


    Crear un servicio WCF en un contexto de SharePoint
    -Si necesita que el servicio se ejecute en el contexto actual de SharePoint
    -Si desea utilizar el soporte completo de API de SharePoint
    -Si desea que su cliente acceda a su servicio con la misma experiencia como los servicios de SharePoint OOB
    -Si se extiende algunos funcionalidad personalizada de su solución que no sea por defecto proporcionados por servicios de SharePoint.
    -Si desea utilizar y proporcionar la misma autenticación/autorización configurada en la granja al acceder a su servicio.
    -Si el servicio será usado entre las granjas de SharePoint.


    Crear un servicio WCF independiente
    -Si desea exponer algunas funcionalidades de su solución al mundo exterior.
    -Sólo puede utilizar la API de cliente / SharePoint webservice / o su referencia de código personalizado dentro de su servicio WCF.
    -Desea prestar atención a la autenticación y autorización
    -Si puede accederlo por otro cliente, sin siquiera conocer la existencia de SharePoint en el back-end.



    Si deseas crear un servicio WCF independiente, es recomendable ejecutar en un sitio web de IIS independiente (No Sharepoint).